/**
 * Copyright (c) 2021 Eclipse contributors and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 */
package org.eclipse.cbi.p2repo.p2.maven.pom.util;

import org.eclipse.cbi.p2repo.p2.maven.pom.Activation;
import org.eclipse.cbi.p2repo.p2.maven.pom.ActivationFile;
import org.eclipse.cbi.p2repo.p2.maven.pom.ActivationOS;
import org.eclipse.cbi.p2repo.p2.maven.pom.ActivationProperty;
import org.eclipse.cbi.p2repo.p2.maven.pom.Build;
import org.eclipse.cbi.p2repo.p2.maven.pom.BuildBase;
import org.eclipse.cbi.p2repo.p2.maven.pom.CiManagement;
import org.eclipse.cbi.p2repo.p2.maven.pom.ConfigurationType;
import org.eclipse.cbi.p2repo.p2.maven.pom.Contributor;
import org.eclipse.cbi.p2repo.p2.maven.pom.ContributorsType;
import org.eclipse.cbi.p2repo.p2.maven.pom.DependenciesType;
import org.eclipse.cbi.p2repo.p2.maven.pom.Dependency;
import org.eclipse.cbi.p2repo.p2.maven.pom.DependencyManagement;
import org.eclipse.cbi.p2repo.p2.maven.pom.DeploymentRepository;
import org.eclipse.cbi.p2repo.p2.maven.pom.Developer;
import org.eclipse.cbi.p2repo.p2.maven.pom.DevelopersType;
import org.eclipse.cbi.p2repo.p2.maven.pom.DistributionManagement;
import org.eclipse.cbi.p2repo.p2.maven.pom.DocumentRoot;
import org.eclipse.cbi.p2repo.p2.maven.pom.ExcludesType;
import org.eclipse.cbi.p2repo.p2.maven.pom.Exclusion;
import org.eclipse.cbi.p2repo.p2.maven.pom.ExclusionsType;
import org.eclipse.cbi.p2repo.p2.maven.pom.ExecutionGoalsType;
import org.eclipse.cbi.p2repo.p2.maven.pom.ExecutionsType;
import org.eclipse.cbi.p2repo.p2.maven.pom.Extension;
import org.eclipse.cbi.p2repo.p2.maven.pom.ExtensionsType;
import org.eclipse.cbi.p2repo.p2.maven.pom.FiltersType;
import org.eclipse.cbi.p2repo.p2.maven.pom.GoalsType;
import org.eclipse.cbi.p2repo.p2.maven.pom.IncludesType;
import org.eclipse.cbi.p2repo.p2.maven.pom.IssueManagement;
import org.eclipse.cbi.p2repo.p2.maven.pom.License;
import org.eclipse.cbi.p2repo.p2.maven.pom.LicensesType;
import org.eclipse.cbi.p2repo.p2.maven.pom.MailingList;
import org.eclipse.cbi.p2repo.p2.maven.pom.MailingListsType;
import org.eclipse.cbi.p2repo.p2.maven.pom.Model;
import org.eclipse.cbi.p2repo.p2.maven.pom.ModulesType;
import org.eclipse.cbi.p2repo.p2.maven.pom.Notifier;
import org.eclipse.cbi.p2repo.p2.maven.pom.NotifiersType;
import org.eclipse.cbi.p2repo.p2.maven.pom.Organization;
import org.eclipse.cbi.p2repo.p2.maven.pom.OtherArchivesType;
import org.eclipse.cbi.p2repo.p2.maven.pom.Parent;
import org.eclipse.cbi.p2repo.p2.maven.pom.Plugin;
import org.eclipse.cbi.p2repo.p2.maven.pom.PluginExecution;
import org.eclipse.cbi.p2repo.p2.maven.pom.PluginManagement;
import org.eclipse.cbi.p2repo.p2.maven.pom.PluginRepositoriesType;
import org.eclipse.cbi.p2repo.p2.maven.pom.PluginsType;
import org.eclipse.cbi.p2repo.p2.maven.pom.PomPackage;
import org.eclipse.cbi.p2repo.p2.maven.pom.Prerequisites;
import org.eclipse.cbi.p2repo.p2.maven.pom.Profile;
import org.eclipse.cbi.p2repo.p2.maven.pom.ProfilesType;
import org.eclipse.cbi.p2repo.p2.maven.pom.PropertiesType;
import org.eclipse.cbi.p2repo.p2.maven.pom.Relocation;
import org.eclipse.cbi.p2repo.p2.maven.pom.ReportPlugin;
import org.eclipse.cbi.p2repo.p2.maven.pom.ReportSet;
import org.eclipse.cbi.p2repo.p2.maven.pom.ReportSetReportsType;
import org.eclipse.cbi.p2repo.p2.maven.pom.ReportSetsType;
import org.eclipse.cbi.p2repo.p2.maven.pom.Reporting;
import org.eclipse.cbi.p2repo.p2.maven.pom.ReportingPluginsType;
import org.eclipse.cbi.p2repo.p2.maven.pom.ReportsType;
import org.eclipse.cbi.p2repo.p2.maven.pom.RepositoriesType;
import org.eclipse.cbi.p2repo.p2.maven.pom.Repository;
import org.eclipse.cbi.p2repo.p2.maven.pom.RepositoryPolicy;
import org.eclipse.cbi.p2repo.p2.maven.pom.Resource;
import org.eclipse.cbi.p2repo.p2.maven.pom.ResourcesType;
import org.eclipse.cbi.p2repo.p2.maven.pom.RolesType;
import org.eclipse.cbi.p2repo.p2.maven.pom.Scm;
import org.eclipse.cbi.p2repo.p2.maven.pom.Site;
import org.eclipse.cbi.p2repo.p2.maven.pom.TestResourcesType;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.util.Switch;

/**
 * <!-- begin-user-doc -->
 * The <b>Switch</b> for the model's inheritance
 * hierarchy. It supports the call {@link #doSwitch(EObject) doSwitch(object)}
 * to invoke the <code>caseXXX</code> method for each class of the model,
 * starting with the actual class of the object and proceeding up the
 * inheritance hierarchy until a non-null result is returned, which is the
 * result of the switch.
 * <!-- end-user-doc -->
 * @see org.eclipse.cbi.p2repo.p2.maven.pom.PomPackage
 * @generated
 */
public class PomSwitch<T> extends Switch<T> {
	/**
	 * The cached model package
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected static PomPackage modelPackage;

	/**
	 * Creates an instance of the switch.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public PomSwitch() {
		if (modelPackage == null) {
			modelPackage = PomPackage.eINSTANCE;
		}
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Activation</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Activation</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseActivation(Activation object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Activation File</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Activation File</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseActivationFile(ActivationFile object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Activation OS</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Activation OS</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseActivationOS(ActivationOS object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Activation Property</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Activation Property</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseActivationProperty(ActivationProperty object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Build</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Build</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseBuild(Build object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Build Base</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Build Base</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseBuildBase(BuildBase object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Ci Management</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Ci Management</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseCiManagement(CiManagement object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Configuration Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Configuration Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseConfigurationType(ConfigurationType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Contributor</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Contributor</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseContributor(Contributor object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Contributors Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Contributors Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseContributorsType(ContributorsType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Dependencies Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Dependencies Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDependenciesType(DependenciesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Dependency</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Dependency</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDependency(Dependency object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Dependency Management</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Dependency Management</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDependencyManagement(DependencyManagement object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Deployment Repository</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Deployment Repository</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDeploymentRepository(DeploymentRepository object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Developer</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Developer</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDeveloper(Developer object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Developers Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Developers Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDevelopersType(DevelopersType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Distribution Management</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Distribution Management</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDistributionManagement(DistributionManagement object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Document Root</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Document Root</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDocumentRoot(DocumentRoot object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Excludes Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Excludes Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseExcludesType(ExcludesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Exclusion</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Exclusion</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseExclusion(Exclusion object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Exclusions Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Exclusions Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseExclusionsType(ExclusionsType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Execution Goals Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Execution Goals Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseExecutionGoalsType(ExecutionGoalsType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Executions Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Executions Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseExecutionsType(ExecutionsType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Extension</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Extension</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseExtension(Extension object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Extensions Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Extensions Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseExtensionsType(ExtensionsType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Filters Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Filters Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseFiltersType(FiltersType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Goals Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Goals Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseGoalsType(GoalsType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Includes Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Includes Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseIncludesType(IncludesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Issue Management</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Issue Management</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseIssueManagement(IssueManagement object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>License</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>License</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseLicense(License object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Licenses Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Licenses Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseLicensesType(LicensesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Mailing List</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Mailing List</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseMailingList(MailingList object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Mailing Lists Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Mailing Lists Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseMailingListsType(MailingListsType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Model</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Model</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModel(Model object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Modules Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Modules Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModulesType(ModulesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Notifier</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Notifier</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseNotifier(Notifier object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Notifiers Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Notifiers Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseNotifiersType(NotifiersType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Organization</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Organization</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseOrganization(Organization object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Other Archives Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Other Archives Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseOtherArchivesType(OtherArchivesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Parent</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Parent</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseParent(Parent object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Plugin</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Plugin</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T casePlugin(Plugin object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Plugin Execution</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Plugin Execution</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T casePluginExecution(PluginExecution object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Plugin Management</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Plugin Management</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T casePluginManagement(PluginManagement object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Plugin Repositories Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Plugin Repositories Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T casePluginRepositoriesType(PluginRepositoriesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Plugins Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Plugins Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T casePluginsType(PluginsType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Prerequisites</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Prerequisites</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T casePrerequisites(Prerequisites object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Profile</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Profile</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseProfile(Profile object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Profiles Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Profiles Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseProfilesType(ProfilesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Properties Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Properties Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T casePropertiesType(PropertiesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Relocation</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Relocation</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseRelocation(Relocation object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Reporting</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Reporting</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseReporting(Reporting object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Reporting Plugins Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Reporting Plugins Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseReportingPluginsType(ReportingPluginsType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Report Plugin</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Report Plugin</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseReportPlugin(ReportPlugin object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Report Set</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Report Set</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseReportSet(ReportSet object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Report Set Reports Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Report Set Reports Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseReportSetReportsType(ReportSetReportsType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Report Sets Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Report Sets Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseReportSetsType(ReportSetsType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Reports Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Reports Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseReportsType(ReportsType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Repositories Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Repositories Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseRepositoriesType(RepositoriesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Repository</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Repository</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseRepository(Repository object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Repository Policy</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Repository Policy</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseRepositoryPolicy(RepositoryPolicy object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Resource</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Resource</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseResource(Resource object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Resources Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Resources Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseResourcesType(ResourcesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Roles Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Roles Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseRolesType(RolesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Scm</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Scm</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseScm(Scm object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Site</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Site</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSite(Site object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Test Resources Type</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Test Resources Type</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseTestResourcesType(TestResourcesType object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>EObject</em>'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>EObject</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject)
	 * @generated
	 */
	@Override
	public T defaultCase(EObject object) {
		return null;
	}

	/**
	 * Calls <code>caseXXX</code> for each class of the model until one returns a non null result; it yields that result.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the first non-null result returned by a <code>caseXXX</code> call.
	 * @generated
	 */
	@Override
	protected T doSwitch(int classifierID, EObject theEObject) {
		switch (classifierID) {
			case PomPackage.ACTIVATION: {
				Activation activation = (Activation) theEObject;
				T result = caseActivation(activation);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.ACTIVATION_FILE: {
				ActivationFile activationFile = (ActivationFile) theEObject;
				T result = caseActivationFile(activationFile);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.ACTIVATION_OS: {
				ActivationOS activationOS = (ActivationOS) theEObject;
				T result = caseActivationOS(activationOS);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.ACTIVATION_PROPERTY: {
				ActivationProperty activationProperty = (ActivationProperty) theEObject;
				T result = caseActivationProperty(activationProperty);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.BUILD: {
				Build build = (Build) theEObject;
				T result = caseBuild(build);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.BUILD_BASE: {
				BuildBase buildBase = (BuildBase) theEObject;
				T result = caseBuildBase(buildBase);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.CI_MANAGEMENT: {
				CiManagement ciManagement = (CiManagement) theEObject;
				T result = caseCiManagement(ciManagement);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.CONFIGURATION_TYPE: {
				ConfigurationType configurationType = (ConfigurationType) theEObject;
				T result = caseConfigurationType(configurationType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.CONTRIBUTOR: {
				Contributor contributor = (Contributor) theEObject;
				T result = caseContributor(contributor);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.CONTRIBUTORS_TYPE: {
				ContributorsType contributorsType = (ContributorsType) theEObject;
				T result = caseContributorsType(contributorsType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.DEPENDENCIES_TYPE: {
				DependenciesType dependenciesType = (DependenciesType) theEObject;
				T result = caseDependenciesType(dependenciesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.DEPENDENCY: {
				Dependency dependency = (Dependency) theEObject;
				T result = caseDependency(dependency);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.DEPENDENCY_MANAGEMENT: {
				DependencyManagement dependencyManagement = (DependencyManagement) theEObject;
				T result = caseDependencyManagement(dependencyManagement);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.DEPLOYMENT_REPOSITORY: {
				DeploymentRepository deploymentRepository = (DeploymentRepository) theEObject;
				T result = caseDeploymentRepository(deploymentRepository);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.DEVELOPER: {
				Developer developer = (Developer) theEObject;
				T result = caseDeveloper(developer);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.DEVELOPERS_TYPE: {
				DevelopersType developersType = (DevelopersType) theEObject;
				T result = caseDevelopersType(developersType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.DISTRIBUTION_MANAGEMENT: {
				DistributionManagement distributionManagement = (DistributionManagement) theEObject;
				T result = caseDistributionManagement(distributionManagement);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.DOCUMENT_ROOT: {
				DocumentRoot documentRoot = (DocumentRoot) theEObject;
				T result = caseDocumentRoot(documentRoot);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.EXCLUDES_TYPE: {
				ExcludesType excludesType = (ExcludesType) theEObject;
				T result = caseExcludesType(excludesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.EXCLUSION: {
				Exclusion exclusion = (Exclusion) theEObject;
				T result = caseExclusion(exclusion);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.EXCLUSIONS_TYPE: {
				ExclusionsType exclusionsType = (ExclusionsType) theEObject;
				T result = caseExclusionsType(exclusionsType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.EXECUTION_GOALS_TYPE: {
				ExecutionGoalsType executionGoalsType = (ExecutionGoalsType) theEObject;
				T result = caseExecutionGoalsType(executionGoalsType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.EXECUTIONS_TYPE: {
				ExecutionsType executionsType = (ExecutionsType) theEObject;
				T result = caseExecutionsType(executionsType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.EXTENSION: {
				Extension extension = (Extension) theEObject;
				T result = caseExtension(extension);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.EXTENSIONS_TYPE: {
				ExtensionsType extensionsType = (ExtensionsType) theEObject;
				T result = caseExtensionsType(extensionsType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.FILTERS_TYPE: {
				FiltersType filtersType = (FiltersType) theEObject;
				T result = caseFiltersType(filtersType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.GOALS_TYPE: {
				GoalsType goalsType = (GoalsType) theEObject;
				T result = caseGoalsType(goalsType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.INCLUDES_TYPE: {
				IncludesType includesType = (IncludesType) theEObject;
				T result = caseIncludesType(includesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.ISSUE_MANAGEMENT: {
				IssueManagement issueManagement = (IssueManagement) theEObject;
				T result = caseIssueManagement(issueManagement);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.LICENSE: {
				License license = (License) theEObject;
				T result = caseLicense(license);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.LICENSES_TYPE: {
				LicensesType licensesType = (LicensesType) theEObject;
				T result = caseLicensesType(licensesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.MAILING_LIST: {
				MailingList mailingList = (MailingList) theEObject;
				T result = caseMailingList(mailingList);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.MAILING_LISTS_TYPE: {
				MailingListsType mailingListsType = (MailingListsType) theEObject;
				T result = caseMailingListsType(mailingListsType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.MODEL: {
				Model model = (Model) theEObject;
				T result = caseModel(model);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.MODULES_TYPE: {
				ModulesType modulesType = (ModulesType) theEObject;
				T result = caseModulesType(modulesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.NOTIFIER: {
				Notifier notifier = (Notifier) theEObject;
				T result = caseNotifier(notifier);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.NOTIFIERS_TYPE: {
				NotifiersType notifiersType = (NotifiersType) theEObject;
				T result = caseNotifiersType(notifiersType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.ORGANIZATION: {
				Organization organization = (Organization) theEObject;
				T result = caseOrganization(organization);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.OTHER_ARCHIVES_TYPE: {
				OtherArchivesType otherArchivesType = (OtherArchivesType) theEObject;
				T result = caseOtherArchivesType(otherArchivesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.PARENT: {
				Parent parent = (Parent) theEObject;
				T result = caseParent(parent);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.PLUGIN: {
				Plugin plugin = (Plugin) theEObject;
				T result = casePlugin(plugin);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.PLUGIN_EXECUTION: {
				PluginExecution pluginExecution = (PluginExecution) theEObject;
				T result = casePluginExecution(pluginExecution);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.PLUGIN_MANAGEMENT: {
				PluginManagement pluginManagement = (PluginManagement) theEObject;
				T result = casePluginManagement(pluginManagement);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.PLUGIN_REPOSITORIES_TYPE: {
				PluginRepositoriesType pluginRepositoriesType = (PluginRepositoriesType) theEObject;
				T result = casePluginRepositoriesType(pluginRepositoriesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.PLUGINS_TYPE: {
				PluginsType pluginsType = (PluginsType) theEObject;
				T result = casePluginsType(pluginsType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.PREREQUISITES: {
				Prerequisites prerequisites = (Prerequisites) theEObject;
				T result = casePrerequisites(prerequisites);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.PROFILE: {
				Profile profile = (Profile) theEObject;
				T result = caseProfile(profile);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.PROFILES_TYPE: {
				ProfilesType profilesType = (ProfilesType) theEObject;
				T result = caseProfilesType(profilesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.PROPERTIES_TYPE: {
				PropertiesType propertiesType = (PropertiesType) theEObject;
				T result = casePropertiesType(propertiesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.RELOCATION: {
				Relocation relocation = (Relocation) theEObject;
				T result = caseRelocation(relocation);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.REPORTING: {
				Reporting reporting = (Reporting) theEObject;
				T result = caseReporting(reporting);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.REPORT_PLUGIN: {
				ReportPlugin reportPlugin = (ReportPlugin) theEObject;
				T result = caseReportPlugin(reportPlugin);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.REPORTING_PLUGINS_TYPE: {
				ReportingPluginsType reportingPluginsType = (ReportingPluginsType) theEObject;
				T result = caseReportingPluginsType(reportingPluginsType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.REPORT_SET: {
				ReportSet reportSet = (ReportSet) theEObject;
				T result = caseReportSet(reportSet);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.REPORT_SET_REPORTS_TYPE: {
				ReportSetReportsType reportSetReportsType = (ReportSetReportsType) theEObject;
				T result = caseReportSetReportsType(reportSetReportsType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.REPORT_SETS_TYPE: {
				ReportSetsType reportSetsType = (ReportSetsType) theEObject;
				T result = caseReportSetsType(reportSetsType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.REPORTS_TYPE: {
				ReportsType reportsType = (ReportsType) theEObject;
				T result = caseReportsType(reportsType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.REPOSITORIES_TYPE: {
				RepositoriesType repositoriesType = (RepositoriesType) theEObject;
				T result = caseRepositoriesType(repositoriesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.REPOSITORY: {
				Repository repository = (Repository) theEObject;
				T result = caseRepository(repository);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.REPOSITORY_POLICY: {
				RepositoryPolicy repositoryPolicy = (RepositoryPolicy) theEObject;
				T result = caseRepositoryPolicy(repositoryPolicy);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.RESOURCE: {
				Resource resource = (Resource) theEObject;
				T result = caseResource(resource);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.RESOURCES_TYPE: {
				ResourcesType resourcesType = (ResourcesType) theEObject;
				T result = caseResourcesType(resourcesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.ROLES_TYPE: {
				RolesType rolesType = (RolesType) theEObject;
				T result = caseRolesType(rolesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.SCM: {
				Scm scm = (Scm) theEObject;
				T result = caseScm(scm);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.SITE: {
				Site site = (Site) theEObject;
				T result = caseSite(site);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			case PomPackage.TEST_RESOURCES_TYPE: {
				TestResourcesType testResourcesType = (TestResourcesType) theEObject;
				T result = caseTestResourcesType(testResourcesType);
				if (result == null)
					result = defaultCase(theEObject);
				return result;
			}
			default:
				return defaultCase(theEObject);
		}
	}

	/**
	 * Checks whether this is a switch for the given package.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param ePackage the package in question.
	 * @return whether this is a switch for the given package.
	 * @generated
	 */
	@Override
	protected boolean isSwitchFor(EPackage ePackage) {
		return ePackage == modelPackage;
	}

} // PomSwitch
